/**************************************
  Header file for auto away functions
  (c) 1999 Jeremy Wise
  GnomeICU
***************************************/

#ifndef __AUTOAWAY_H__
#define __AUTOAWAY_H__

#include <glib.h>

extern gint autoaway_timeout_tag;
extern gchar *auto_away_message;
extern gchar *auto_na_message;

guint auto_away (void);

#endif /* __AUTOAWAY_H__ */
